@@ -19,7 +19,7 @@
  * You should have received a copy of the GNU General Public License
  * along with "prooftree". If not, see <http://www.gnu.org/licenses/>.
  * 
- * $Id: draw_tree.ml,v 1.35 2012-01-02 15:50:50 tews Exp $
+ * $Id: draw_tree.ml,v 1.38 2012-05-14 14:03:36 tews Exp $
  *)
 
 
@@ -50,8 +50,8 @@
     running time is independent of the size of the complete tree. When
     a new node is inserted into the tree, only its direct and indirect
     parent nodes need to recompute their layout data. No sibling node
-    must be visited. The achieve this the nodes do not store absolut
-    positions. Instead nodes only store the width and height of
+    must be visited. To achieve this the nodes do not store absolut
+    positions. Instead, nodes only store the width and height of
     themselves and of their subtrees. 
 
     Adjusting the tree layout when new elements are inserted works
@@ -305,8 +305,8 @@ end
 
 (** [set_children parent children] correctly insert [children] into
     the doubly linked tree as children of node [parent]. After the
-    change {!children_changed} is called on [parent]. Asserts that the
-    children list of [parent] is empty.
+    change {!doubly_linked_tree.children_changed} is called on
+    [parent]. Asserts that the children list of [parent] is empty.
 *)
 let set_children parent children =
   assert(parent#children = []);
@@ -316,8 +316,8 @@ let set_children parent children =
 
 
 (** [clear_children parent] removes all children from [parent] from
-    the doubly linked tree. After the change {!children_changed} is
-    called on [parent].
+    the doubly linked tree. After the change
+    {!doubly_linked_tree.children_changed} is called on [parent].
 *)
 let clear_children parent =
   List.iter (fun c -> c#clear_parent) parent#children;
@@ -348,11 +348,36 @@ let clear_children parent =
 (*****************************************************************************)
 (*****************************************************************************)
 
+(** Abstract class type for external {!class: Node_window.node_window}'s
+    containing just those methods that are needed here. This class
+    type is used to break the circular dependency between {!Draw_tree}
+    and {!Node_window}. All {!proof_tree_element}'s keep a list of
+    their external windows to update them. External node windows have
+    a pointer to proof-tree elements to deregister themselves when
+    they get deleted or orphaned. Before external node windows are
+    passed to functions in this module, they must be cast to this
+    class type.
+*)
 class type external_node_window =
 object
+  (** Number of this node window. Used to correlate node windows with
+      the proof-tree display.
+  *)
   method window_number : string
+
+  (** Set the content in the text buffer of this node window *)
   method update_content : string -> unit
+
+  (** Reconfigure and redraw the node window. Needs to be called when
+      the configuration has been changed. Actually only the font of
+      the buffer text is changed.
+  *)
   method configuration_updated : unit
+
+  (** Delete this node window if it is not sticky. Needs to be called
+      when the corresponding element in the proof-tree display is
+      deleted.
+  *)
   method delete_non_sticky_node_window : unit
 end
 
@@ -363,7 +388,11 @@ end
 (*****************************************************************************)
 (*****************************************************************************)
 
-(** Abstract base class for turnstiles and proof commands.
+
+(** Abstract base class for turnstiles and proof commands. Contains
+    the code for (relativ) layout, (absolute) coordinates, locating
+    mouse button clicks, marking branches and the general drawing
+    functions.
 *)
 class virtual proof_tree_element drawable
     debug_name inst_existentials fresh_existentials = 
@@ -376,15 +405,23 @@ object (self)
   (***************************************************************************)
   (***************************************************************************)
 
-  val debug_name = (debug_name : string)
-  method debug_name = debug_name
+  (** ID for debugging purposes *)
+  method debug_name = (debug_name : string)
 
+  (** The kind of this element. *)
   method virtual node_kind : node_kind
 
+  (** The existentials created for this element. Only non-nil when
+      this is a proof command.
+  *)
   method fresh_existentials = fresh_existentials
 
+  (** The existentials instantiated by this element. Only non-nil when
+      this is a proof command. 
+  *)
   method inst_existentials : existential_variable list = inst_existentials
 
+  (** The {!Gtk_ext.better_drawable} into which this element draws itself. *)
   val drawable = drawable
 
   (** The width of this node alone in pixels. Set in the initializer
@@ -406,7 +443,7 @@ object (self)
       the subtree which has the first child as root. Always
       non-negative. Zero if this node has no children. Usually zero,
       non-zero only in unusual cases, for instance if the {!width} of
-      this node is larger than the total width of all children
+      this node is larger than the total width of all children.
   *)
   val mutable first_child_offset = 0
 
@@ -416,13 +453,23 @@ object (self)
   *)
   val mutable x_offset = 0
 
-  (** The height of this nodes subtree. *)
+  (** The height of this nodes subtree, counted in tree levels. At
+      least 1, because this element occupies already some level. 
+  *)
   val mutable subtree_levels = 0
 
+  (** The proof state of this node. *)
   val mutable branch_state = Unproven
+
+  (** [true] if this node is selected and displayed in the sequent
+      area of the proof-tree window.
+  *)
   val mutable selected = false
+
+  (** The list of external node windows. *)
   val mutable external_windows : external_node_window list = []
 
+  (** The set of all existentials for this node. *)
   val mutable existential_variables = fresh_existentials
 
   (***************************************************************************)
@@ -431,23 +478,59 @@ object (self)
   (***************************************************************************)
   (***************************************************************************)
 
+  (** Accessor method of {!attribute: width}. *)
   method width = width
+
+  (** Accessor method of {!attribute: height}. *)
   method height = height
+
+  (** Accessor method of {!attribute: subtree_width}. *)
   method subtree_width = subtree_width
+
+  (** Accessor method of {!attribute: subtree_levels}. *)
   method subtree_levels = subtree_levels
+
+  (** Accessor method of {!attribute: x_offset}. *)
   method x_offset = x_offset
+
+  (** Accessor method of {!attribute: branch_state}. *)
   method branch_state = branch_state
+
+  (** Modification method of {!attribute: branch_state}. *)
   method set_branch_state s = branch_state <- s
+
+  (** Accessor method of {!attribute: selected}. *)
   method is_selected = selected
+
+  (** Modification method of {!attribute: selected}. *)
   method selected b = selected <- b
 
+
+  (** Accessor method of {!attribute: existential_variables}. *)
   method existential_variables = existential_variables
 
+  (** [inherit_existentials exl] sets this nodes {!attribute:
+      existential_variables} as union of {!fresh_existentials} and
+      [exl].
+  *)
   method inherit_existentials existentials =
     existential_variables <- List.rev_append fresh_existentials existentials
 
+  (** The original text content associated with this element. For
+      turnstiles this is the sequent text and for proof commands this is the
+      complete proof command.
+  *)
   method virtual content : string
+
+  (** [true] if the proof command is abbreviated in the display.
+      Always [false] for turnstiles. Used to decide whether to display
+      tooltips for proof commands.
+  *)
   method virtual content_shortened : bool
+
+  (** Return the sequent ID for turnstiles and the empty string for
+      proof commands. For turnstiles the sequent ID is used as
+      {!debug_name}. *)
   method virtual id : string
 
 
@@ -495,16 +578,22 @@ object (self)
   (***************************************************************************)
   (***************************************************************************)
 
+  (** Compute the height of the subtree of this element in pixels. *)
   method subtree_height = 
     (subtree_levels - 1) * !current_config.level_distance + 
       2 * !current_config.turnstile_radius +
       2 * !current_config.turnstile_line_width
 
-  (** Sets the {!width} and {!height} fields. Called in the 
-      initializer of the heirs.
+  (** Sets the {!width} and {!height} fields. Called in the
+      initializer of the heirs and when the configuration has been
+      updated.
   *)
   method private virtual set_node_size : unit
 
+  (** (Re-)compute all (relative) layout information for this node.
+      Computes and sets {!attribute: subtree_levels}, {!attribute:
+      subtree_width}, {!attribute: x_offset} and
+      {!first_child_offset}. *)
   method private update_subtree_size =
     let (children_width, max_levels, last_child) = 
       List.fold_left 
@@ -591,6 +680,9 @@ object (self)
      *   subtree_levels;
      *)
 	
+  (** Do {!update_subtree_size} in this element and all parent
+      elements up to the root of the tree.
+  *)
   method update_sizes_in_branch =
     (* 
      * let old_subtree_width = subtree_width in
@@ -672,20 +764,27 @@ object (self)
   (***************************************************************************)
   (***************************************************************************)
 
-  (** Draw just this node (without connecting lines) at the indicated
-      position. First argument [left] is the left border, second
-      argument [y] is the y-coordinate.
+  (** Draw just this element (without connecting lines) at the
+      indicated position. First argument [left] is the left border,
+      second argument [y] is the y-coordinate. 
   *)
   method private virtual draw : int -> int -> unit
 
-  (* line_offset inverse_slope => (x_off, y_off) *)
+  (** [line_offset inverse_slope] computes the start offset (as
+      [(x_off, y_off)]) for drawing a line that start or ends in this
+      node with inverse slope [inverse_slope]. These offsets are
+      needed to avoid overdrawing elements with connecting lines. The
+      parameter is the inverse slope, because it is always defined,
+      because we never draw horizontal lines. Vertical lines do
+      appear, for them the real slope is infinite. 
+  *)
   method virtual line_offset : float -> (int * int)
 
 
   (** Draw the lines from this node to all its children. 
 
       @param left x-coordinate of the left side of the bounding box of
-                  this node's subtree
+      this node's subtree
       @param y y-coordinate of this node
   *)
   method private draw_lines left y =
@@ -705,7 +804,7 @@ object (self)
 	restore_gc drawable gc_opt)
 
 
-  (** Draw this node's subtree given the left side of the bounding box
+  (** Draw this element's subtree given the left side of the bounding box
       and the y-coordinate of this node. This is the internal draw method 
       that iterates through the tree.
 
@@ -717,7 +816,7 @@ object (self)
     (* 
      * Printf.fprintf (debugc())
      * "DST %s parent %s childs %s width %d tree_width %d\n%!"
-     *   debug_name
+     *   self#debug_name
      *   (match parent with
      * 	| None -> "None"
      * 	| Some p -> p#debug_name)
@@ -805,12 +904,20 @@ object (self)
   (***************************************************************************)
   (***************************************************************************)
 
+  (** Apply (the marking function) [f] on this node and all parent
+      nodes until [f] returns [false] or the root is reached. 
+  *)
   method mark_branch (f : proof_tree_element -> bool) =
     if f (self :> proof_tree_element) then
       match parent with
 	| Some p -> p#mark_branch f
 	| None -> ()
 
+  (** Mark this element as [CurrentNode] and all the parent nodes as
+      [Current] branch, see {!branch_state_type}. Relies on the
+      invariant that the parent of a [Current] element is also marked
+      [Current].
+  *)
   method mark_current =
     self#mark_branch 
       (fun (self : proof_tree_element) -> 
@@ -820,6 +927,10 @@ object (self)
 	  (self#set_branch_state Current; true));
     branch_state <- CurrentNode
 
+  (** Mark this element as [Proven] and mark all parents [Proven]
+      until one parent has an unproven child, see
+      {!branch_state_type}.
+  *)
   method mark_proved =
     self#mark_branch
       (fun (self : proof_tree_element) ->
@@ -833,6 +944,10 @@ object (self)
 	else false
       )
 
+  (** Mark this node as [Cheated] and mark all parents that have only
+      [Cheated] children as [Cheated] as well, see
+      {!branch_state_type}.
+  *)
   method mark_cheated =
     self#mark_branch
       (fun (self : proof_tree_element) ->
@@ -841,6 +956,10 @@ object (self)
 	else false
       )
 
+  (** Remove the [Current] and [CurrentNode] marking for the current
+      branch up to the root and set the marking of these nodes to
+      [Unproven], see {!branch_state_type}.
+  *)
   method unmark_current =
     self#mark_branch
       (fun (self : proof_tree_element) ->
@@ -853,6 +972,10 @@ object (self)
 	  | Cheated -> assert false
       )
 
+  (** Remove the [Proved] or [Cheated] mark of this element and all
+      parent elements until an [Unproven] or [Current] element is met,
+      see {!branch_state_type}. 
+  *)
   method unmark_proved_or_cheated =
     self#mark_branch
       (fun (self : proof_tree_element) ->
@@ -864,6 +987,11 @@ object (self)
 	  | Current -> false
       )
 
+  (** Set all [Current] and [CurrentNode] markings in the subtree of
+      this element to [Unproven], see {!branch_state_type}. Used when
+      the proof-tree window gets disconnected from the current
+      proof.
+  *)
   method disconnect_proof =
     (match branch_state with
       | Current
@@ -881,6 +1009,10 @@ object (self)
   (***************************************************************************)
   (***************************************************************************)
 
+  (** Return the displayed sequent text for turnstile elements, which
+      contains additional information about uninstantiated and
+      partially instantiated existentials.
+  *)
   method displayed_text =
     let uninst_ex = filter_uninstantiated existential_variables in
     let partial_ex = filter_partially_instantiated existential_variables in
@@ -901,9 +1033,13 @@ object (self)
 	  ^ (string_of_existential_list partial_ex)
 	else "")
 
+  (** Register an external window for this element. *)
   method register_external_window win =
     external_windows <- win :: external_windows
 
+  (** Delete an external window from the list of registered external
+      windows.
+  *)
   method delete_external_window win =
     external_windows <- List.filter (fun w -> w <> win) external_windows
 
@@ -912,14 +1048,27 @@ object (self)
   method delete_non_sticky_external_windows =
     List.iter (fun w -> w#delete_non_sticky_node_window) external_windows
 
+  (** Propagate this nodes existentials to all its children. This
+      method is not recursive. It is used during normal operation,
+      where newly added children have themselves no children.
+  *)
   method private set_children_existentials =
     List.iter (fun c -> c#inherit_existentials existential_variables)
       children
 
+  (** Propagate existentials recursively down to all children in the
+      complete subtree of this element. Necessary after proof-tree
+      cloning, because cloning works bottom-up.
+  *)
   method propagate_existentials =
     self#set_children_existentials;
     List.iter (fun c -> c#propagate_existentials) children
 
+  (** Update the list of existential variables in displayed sequent
+      text in the whole subtree of this element. This needs to be
+      called when some existential got instantiated or when an undo
+      uninstantiates some existential.
+  *)
   method update_existentials_display =
     (if external_windows <> [] && existential_variables <> [] 
      then
@@ -928,12 +1077,20 @@ object (self)
     );
     List.iter (fun c -> c#update_existentials_display) children	
 
+  (** Hook to be called when the list of children has been changed.
+      Adjusts the relative layout information of this element and all its
+      parents and (non-recursively) propagates the existentials to all
+      children.
+  *)
   method children_changed =
     (* prerr_endline("CHILDS at  " ^ self#debug_name ^ " CHANGED"); *)
     self#update_sizes_in_branch;
     self#set_children_existentials
     (* prerr_endline "END CHILD CHANGED" *)
 
+  (** Adjust layout and size information after the configuration has
+      been changed. 
+  *)
   method configuration_updated =
     List.iter (fun ex -> ex#configuration_updated) external_windows;
     self#set_node_size;
@@ -949,20 +1106,39 @@ end
 (*****************************************************************************)
 (*****************************************************************************)
 
+(** Specific element class for sequents, which draw themselves as
+    turnstile symbols. This class specializes the abstract
+    {!proof_tree_element} class for sequent nodes in the proof tree.
+*)
 class turnstile (drawable : better_drawable) sequent_id sequent_text =
 object (self)
   inherit proof_tree_element drawable sequent_id [] [] as super
 
-  val mutable sequent_id = sequent_id
+  (** The pure sequent text. *)
   val mutable sequent_text = (sequent_text : string)
+
+  (** Pango layout for rendering text. Only created if there an ID for
+      an external window must be put into the display.
+  *)
   val mutable layout = None
 
+  (** This is a [Turnstile] node. *)
   method node_kind = Turnstile
 
+  (** Return the pure sequent text as content. *)
   method content = sequent_text
+
+  (** This method is not relevant for sequent elements. Return always
+      false.
+  *)
   method content_shortened = false
 
+  (** Make the sequent ID accessible, which is used as debugging name
+      for sequent elements.
+  *)
   method id = sequent_id
+
+  (** Update the sequent text. *)
   method update_sequent new_text = 
     sequent_text <- new_text;
     let new_text = self#displayed_text in
@@ -970,6 +1146,9 @@ object (self)
       (fun ew -> ew#update_content new_text)
       external_windows
 
+  (** Return the pango layout object of {!layout}. Create one if there
+      is none.
+  *)
   method private get_layout =
     match layout with
       | None -> 
@@ -980,10 +1159,16 @@ object (self)
 	l
       | Some l -> l
 
+  (** Update fonts, sizes and layout after the configuration has been
+      changed.
+  *)
   method configuration_updated =
     layout <- None;
     super#configuration_updated
 
+  (** Draw the turnstile symbol for this sequent at the indicated
+      coordinates.
+  *)
   method private draw_turnstile x y =
     let radius = !current_config.turnstile_radius in
     if branch_state = CurrentNode
@@ -1022,17 +1207,20 @@ object (self)
   (** Draw this turnstile node.
 
       @param left x-coordinate of the left side of the bounding box of
-                  this node's subtree
+      this node's subtree
       @param y y-coordinate of this node
   *)
   method private draw left y =
     let x = self#get_x_coordinate left in
     (* 
      * Printf.fprintf (debugc()) "DRAW TURN %s l %d t %d x %d y %d\n%!" 
-     *   debug_name left top x y;
+     *   self#debug_name left top x y;
      *)
     self#draw_turnstile x y
 
+  (** Compute the line offsets for sequent nodes, see
+      {!proof_tree_element.line_offset}
+  *)
   method line_offset slope =
     let radius = !current_config.turnstile_radius + !current_config.line_sep in
     let d_y = sqrt(float_of_int(radius * radius) /. (slope *. slope +. 1.0)) in
@@ -1040,6 +1228,7 @@ object (self)
     (int_of_float(d_x +. 0.5), int_of_float(d_y +. 0.5))
 
       
+  (** Set width and height of this node. *)
   method private set_node_size =
     width <- 
       2 * !current_config.turnstile_radius +
@@ -1077,6 +1266,10 @@ let make_layout context =
   context#set_font_description !proof_tree_font_desc;
   context#create_layout
 
+(** Specific element class for proof commands. This class specializes
+    the generic and abstract {!proof_tree_element} for proof-command
+    nodes.
+*)
 class proof_command (drawable_arg : better_drawable) 
   command debug_name inst_existentials fresh_existentials =
 object (self)
@@ -1084,25 +1277,54 @@ object (self)
     inst_existentials fresh_existentials 
     as super
 
+  (** The part of the proof command that is displayed inside the tree.
+      Maybe shorter than {!command}.
+  *)
   val mutable displayed_command = ""
+
+  (** The original proof command. If it exceeds the length specified
+      in field [proof_command_length] (see {!Configuration.t} and
+      {!Configuration.current_config}) then only a part of it is
+      displayed in the tree display. *)
   val command = command
+
+  (** Flag to indicate that only a part of the proof command is
+      displayed inside the proof-tree display. Used to decide whether to
+      display tool-tips for this proof command.
+  *)
   val mutable content_shortened = false
 
   (* XXX Pango.Layout.set_font_description is missing in debian
    * squeeze. Have to use Pango.Context.set_font_description and
    * create new layout objects on every font change.
    *)
+  (** The pango layout for rendering the proof command text. *)
   val mutable layout = make_layout drawable_arg#pango_context
+
+  (** Width (in pixels) of the rendered proof command text. *)
   val mutable layout_width = 0
+
+  (** Height (in pixels) of the rendered proof command text. *)
   val mutable layout_height = 0
 
+  (** This is a [Proof_command] element, see {!node_kind}. *)
   method node_kind = Proof_command
 
+  (** Return the original complete proof command as content. *)
   method content = command
+
+  (** Return whether the proof command has been shortend in the
+      display. Used to decide whether to display tool-tips for this
+      proof command.
+  *)
   method content_shortened = content_shortened
 
+  (** This method is not relevant for proof commands. Return the empty
+      string.
+  *)
   method id = ""
 
+  (** Render the proof command in the pango layout. *)
   method private render_proof_command =
     let layout_text = 
       match external_windows with
@@ -1114,6 +1336,9 @@ object (self)
     layout_width <- w;
     layout_height <- h
 
+  (** Set {!displayed_command}. Called from the initializer and when
+      the configuration has been changed.
+  *)
   method private set_displayed_command =
     if Util.utf8_string_length command <= !current_config.proof_command_length
     then begin
@@ -1123,28 +1348,42 @@ object (self)
       content_shortened <- true;
       displayed_command <-
 	(Util.utf8_string_sub command (!current_config.proof_command_length - 1))
-        ^ "\226\128\166" 			(* append horizontal ellipsis *)
+      ^ "\226\128\166" 			(* append horizontal ellipsis *)
     end
 
+  (** Set {!proof_tree_element.width} and {!proof_tree_element.height}
+      after rendering the proof command.
+  *)
   method private set_node_size =
     self#render_proof_command;
     width <- layout_width + !current_config.subtree_sep;
     height <- layout_height
 
+  (** Update fonts, the displayed command, the size and layout
+      information after the configuration has been updated.
+  *)
   method configuration_updated =
     self#set_displayed_command;
     layout <- make_layout drawable_arg#pango_context;
     super#configuration_updated
 
+  (** Override {!proof_tree_element.register_external_window} because
+      the displayed proof command must be rerendered when an external
+      window is registered.
+  *)
   method register_external_window win =
     super#register_external_window win;
     self#render_proof_command
 
+  (** Override {!proof_tree_element.delete_external_window} because
+      the displayed proof command must be rerendered when an external
+      window is deleted.
+  *)
   method delete_external_window win =
     super#delete_external_window win;
     self#render_proof_command
 
-  (** Draw this command node.
+  (** Draw just this command node.
 
       @param left x-coordinate of the left side of the bounding box of
       this node's subtree
@@ -1154,7 +1393,7 @@ object (self)
     let x = self#get_x_coordinate left in
     (* 
      * Printf.fprintf (debugc()) "DRAW TURN %s l %d t %d x %d y %d\n%!" 
-     *   debug_name left top x y;
+     *   self#debug_name left top x y;
      *)
     let crea = List.exists (fun e -> e.existential_mark) fresh_existentials in
     let inst = List.exists (fun e -> e.existential_mark) inst_existentials in
@@ -1178,6 +1417,9 @@ object (self)
       drawable#rectangle 
 	~x:(x - w/2) ~y:(y - h/2) ~width:w ~height:h ();
 
+  (** Compute the line offsets for proof-command nodes, see
+      {!proof_tree_element.line_offset}
+  *)
   method line_offset slope = 
     let sign = if slope >= 0.0 then 1 else -1 in
     let line_sep = !current_config.line_sep in
